@@ -34,21 +34,21 @@ KSysGuardProcessListHelper::KSysGuardProcessListHelper()
 #define GET_PID(i) parameters.value(QString("pid%1").arg(i), -1).toULongLong(); if(pid < 0) return ActionReply(ActionReply::HelperErrorType);
 ActionReply KSysGuardProcessListHelper::sendsignal(QVariantMap parameters) {
     ActionReply reply(ActionReply::HelperErrorType);
-    if(!parameters.contains("signal")) {
-        reply.setErrorDescription("Internal error - no signal parameter was passed to the helper");
+    if(!parameters.contains(QStringLiteral("signal"))) {
+        reply.setErrorDescription(QStringLiteral("Internal error - no signal parameter was passed to the helper"));
         reply.setErrorCode(static_cast<ActionReply::Error>(KSysGuard::Processes::InvalidPid));
         return reply;
     }
-    if(!parameters.contains("pidcount")) {
-        reply.setErrorDescription("Internal error - no pidcount parameter was passed to the helper");
+    if(!parameters.contains(QStringLiteral("pidcount"))) {
+        reply.setErrorDescription(QStringLiteral("Internal error - no pidcount parameter was passed to the helper"));
         reply.setErrorCode(static_cast<ActionReply::Error>(KSysGuard::Processes::InvalidParameter));
         return reply;
     }
 
     KSysGuard::ProcessesLocal processes;
-    int signal = qvariant_cast<int>(parameters.value("signal"));
+    int signal = qvariant_cast<int>(parameters.value(QStringLiteral("signal")));
     bool success = true;
-    int numProcesses = parameters.value("pidcount").toInt();
+    int numProcesses = parameters.value(QStringLiteral("pidcount")).toInt();
     QStringList errorList;
     for (int i = 0; i < numProcesses; ++i) {
         qlonglong pid = GET_PID(i);
@@ -60,20 +60,20 @@ ActionReply KSysGuardProcessListHelper::sendsignal(QVariantMap parameters) {
     if(success) {
         return ActionReply::SuccessReply();
     } else {
-        reply.setErrorDescription(QString("Could not send signal to: ") + errorList.join(", "));
+        reply.setErrorDescription(QStringLiteral("Could not send signal to: ") + errorList.join(QStringLiteral(", ")));
         reply.setErrorCode(static_cast<ActionReply::Error>(KSysGuard::Processes::Unknown));
         return reply;
     }
 }
 
 ActionReply KSysGuardProcessListHelper::renice(QVariantMap parameters) {
-    if(!parameters.contains("nicevalue") || !parameters.contains("pidcount"))
+    if(!parameters.contains(QStringLiteral("nicevalue")) || !parameters.contains(QStringLiteral("pidcount")))
         return ActionReply(ActionReply::HelperErrorType);
 
     KSysGuard::ProcessesLocal processes;
-    int niceValue = qvariant_cast<int>(parameters.value("nicevalue"));
+    int niceValue = qvariant_cast<int>(parameters.value(QStringLiteral("nicevalue")));
     bool success = true;
-    int numProcesses = parameters.value("pidcount").toInt();
+    int numProcesses = parameters.value(QStringLiteral("pidcount")).toInt();
     for (int i = 0; i < numProcesses; ++i) {
         qlonglong pid = GET_PID(i);
         success = processes.setNiceness(pid, niceValue) && success;
@@ -85,14 +85,14 @@ ActionReply KSysGuardProcessListHelper::renice(QVariantMap parameters) {
 }
 
 ActionReply KSysGuardProcessListHelper::changeioscheduler(QVariantMap parameters) {
-    if(!parameters.contains("ioScheduler") || !parameters.contains("ioSchedulerPriority") || !parameters.contains("pidcount"))
+    if(!parameters.contains(QStringLiteral("ioScheduler")) || !parameters.contains(QStringLiteral("ioSchedulerPriority")) || !parameters.contains(QStringLiteral("pidcount")))
         return ActionReply(ActionReply::HelperErrorType);
 
     KSysGuard::ProcessesLocal processes;
-    int ioScheduler = qvariant_cast<int>(parameters.value("ioScheduler"));
-    int ioSchedulerPriority = qvariant_cast<int>(parameters.value("ioSchedulerPriority"));
+    int ioScheduler = qvariant_cast<int>(parameters.value(QStringLiteral("ioScheduler")));
+    int ioSchedulerPriority = qvariant_cast<int>(parameters.value(QStringLiteral("ioSchedulerPriority")));
     bool success = true;
-    int numProcesses = parameters.value("pidcount").toInt();
+    int numProcesses = parameters.value(QStringLiteral("pidcount")).toInt();
     for (int i = 0; i < numProcesses; ++i) {
         qlonglong pid = GET_PID(i);
         success = processes.setIoNiceness(pid, ioScheduler, ioSchedulerPriority) && success;
@@ -104,15 +104,15 @@ ActionReply KSysGuardProcessListHelper::changeioscheduler(QVariantMap parameters
 
 }
 ActionReply KSysGuardProcessListHelper::changecpuscheduler(QVariantMap parameters) {
-    if(!parameters.contains("cpuScheduler") || !parameters.contains("cpuSchedulerPriority") || !parameters.contains("pidcount"))
+    if(!parameters.contains(QStringLiteral("cpuScheduler")) || !parameters.contains(QStringLiteral("cpuSchedulerPriority")) || !parameters.contains(QStringLiteral("pidcount")))
         return ActionReply(ActionReply::HelperErrorType);
 
     KSysGuard::ProcessesLocal processes;
-    int cpuScheduler = qvariant_cast<int>(parameters.value("cpuScheduler"));
-    int cpuSchedulerPriority = qvariant_cast<int>(parameters.value("cpuSchedulerPriority"));
+    int cpuScheduler = qvariant_cast<int>(parameters.value(QStringLiteral("cpuScheduler")));
+    int cpuSchedulerPriority = qvariant_cast<int>(parameters.value(QStringLiteral("cpuSchedulerPriority")));
     bool success = true;
 
-    int numProcesses = parameters.value("pidcount").toInt();
+    int numProcesses = parameters.value(QStringLiteral("pidcount")).toInt();
     for (int i = 0; i < numProcesses; ++i) {
         qlonglong pid = GET_PID(i);
         success = processes.setScheduler(pid, cpuScheduler, cpuSchedulerPriority) && success;
